#
# PST module Crop - draw white rectangle on desired place
# 
# (c) 2002  Tomas Valla   <valla@atrey.karlin.mff.cuni.cz>
# 
# This software may be used and distributed under the terms
# of the GNU General Public License. See COPYING for details.
#
#
#
#
#
# Options:
# llx=<unit>  lower left x coordinate
# lly=<unit>  y coordinate
# urx=<unit>  upper right x coordinate
# ury=<unit>  y coord.
#


package Crop;
use OM;
@ISA = qw(OM);   # derived from OM
use strict;
use sizes;



sub new {
	my $proto = shift;
	my $class = ref($proto) || $proto;
	my $self = OM->new;

	$self->name("Crop");
	$self->{LLX} = undef;   # rectangle coordinates
	$self->{LLY} = undef;
	$self->{URX} = undef;
	$self->{URY} = undef;

	return bless($self,$class);
}


sub parse_options {
	my $self = shift;
	my $str = "";

	$self->log(4,"parsing options");
	while (my $s = shift) { $str .= $s }

	foreach my $e (split /;/, $str) {
		$e =~ s/\s//g;
		if ($e !~ /^(llx|lly|urx|ury)\=(\w+)$/) {
			$self->die("bad option ($e)\n");
		}
		my $key = $1;
		my $val = unit_size($2);
		$self->die($val) if $val =~ /^ERROR/;
		$key =~ tr/[a-z]/[A-Z]/;
		$self->{$key} = $val;
	}
	if(!defined $self->{LLX} || !defined $self->{LLY} || !defined $self->{URX} || !defined $self->{URY})
		{ $self->die("I need options\n") }
	$self->log(2,"rectangle to be cropped: ",
		$self->{LLX}," ",$self->{LLY}," ",$self->{URX}," ",$self->{URY});
}

sub write_page_prolog {
	my $self = shift;
	my $page = shift;
	my $f = $self->{OUTPUT};

	$self->log(4,"writing page $page prolog");
	print $f   # prevent executing of showpage,copypage,erasepage 
		"userdict/PSTdict save put\n",
		"/showpage{}def/copypage{}def/erasepage{}def\n";
}

sub write_page_epilog {
	my $self = shift;
	my $page = shift;
	my $f = $self->{OUTPUT};

	$self->log(4,"writing page $page epilog (with rectangle drawing)");
	print $f
		"PSTmatrix setmatrix\n",
		"1 setgray\n",  # set color to white
		"newpath ",$self->{LLX}," ",$self->{LLY}," moveto ",  # start at lower left point
		$self->{URX}," ",$self->{LLY}," lineto ",   # bottom line
		$self->{URX}," ",$self->{URY}," lineto ",   # right line
		$self->{LLX}," ",$self->{URY}," lineto closepath\n",  # top line and back to ll
		"fill\n",  # draw rectangle
                "userdict/PSTmatrix matrix currentmatrix put\n",
                #"userdict/PSTclip{0 0 moveto\n",
                #$pw," 0 rlineto 0 ",$ph," rlineto -",$pw," 0 rlineto\n",
                #"closepath}put initclip\n",
                "PSTxform concat\n",
		"PSTdict restore showpage\n";   # restore state and draw page
}


1;  # no init
